@@ -1,21 +1,22 @@
-/* $Id: dlog.c 79 2005-06-04 19:07:59Z lennart $ */
+/* $Id: dlog.c 109 2005-11-24 13:44:19Z lennart $ */
 
 /*
  * This file is part of libdaemon.
  *
- * libdaemon is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * libdaemon is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
  *
  * libdaemon is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with libdaemon; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with libdaemon; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,15 +30,15 @@
 #include "dlog.h"
 
 enum daemon_log_flags daemon_log_use = DAEMON_LOG_AUTO|DAEMON_LOG_STDERR;
-char* daemon_log_ident = NULL;
+const char* daemon_log_ident = NULL;
 
 void daemon_log(int prio, const char* template, ...) {
     va_list arglist;
     va_start(arglist, template);
+
     if (daemon_log_use & DAEMON_LOG_SYSLOG) {
-	openlog(daemon_log_ident ? daemon_log_ident : "UNKNOWN", LOG_PID|LOG_NDELAY, LOG_DAEMON);
-        vsyslog(prio, template, arglist);
-	closelog();
+	openlog(daemon_log_ident ? daemon_log_ident : "UNKNOWN", LOG_PID, LOG_DAEMON);
+        vsyslog(prio | LOG_DAEMON, template, arglist);
     }
 
     if (daemon_log_use & DAEMON_LOG_STDERR) {
